| Title: | Make 'ggplot2' Fully Accessible by Generating Alternative Text |
|---|---|
| Description: | Generate alternative texts from 'ggplot2' objects. |
| Authors: | Joseph Barbier [aut, cre] |
| Maintainer: | Joseph Barbier <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-28 06:36:37 UTC |
| Source: | https://github.com/y-sunflower/ggalttext |
generate_alt_text() takes any ggplot2 object and generates
a string that describes what contains the chart.
The description isn't meant to exactly describe the chart, nor how it was made. Instead, it tries to be short and gives an overview of what's inside the chart such as:
the kind of chart(s)
the number of chart(s) for facets
the title, subtitle and caption
Learn more: https://www.section508.gov/create/alternative-text/
generate_alt_text(p, from = c("default", "auto", "origin"), lang = "en")generate_alt_text(p, from = c("default", "auto", "origin"), lang = "en")
p |
A |
from |
Method used to select alt text. Since ggplot2 objects can
include built-in alt text (via |
lang |
Language used for generated text. Defaults to |
A string